/*

Display.js

Copyright (c) 2006 Scue

www.scue.co.uk (www.scue.co.uk/widgets/)
info@scue.co.uk
developer: aidan kane (aidan@scue.co.uk)

see LICENSE for details of the license

*/


// Display provides the layer that sits between the html and the rest of the code

function Display()
{
	this.progInd = null;
	this.flipButton = null;

	this.recipientList = null;
	this.subjectList = null;
}

Display.prototype = 
{
	// setup our flip and progress indicator controls
	init : function(doneButtonOnClick,storedRecipients,storedSubjects)
	{
		// create the done button on the back
		var doneButton = document.getElementById('done');
		createGenericButton(doneButton, 'Done', doneButtonOnClick);

		// create the progress indicator for the front
		this.progInd = new ProgressIndicator(document.getElementById('progressInd'), "images/progress/prog");

		// bind the lists to the html elements and fire them up
		this.recipientList = new EditableList();
		this.subjectList = new EditableList();
		this.recipientList.init(document.getElementById('recipient'),document.getElementById('realRecipient'),storedRecipients,"clear recipient list...","to");
		this.subjectList.init(document.getElementById('subject'),document.getElementById('realSubject'),storedSubjects,"clear subject list...","subject");
	},	

	// updates the div that holds result of sending the message
	showResult : function(messageToDisplay)
	{
		var resultMessage = document.getElementById('resultMessage');
		resultMessage.innerHTML = messageToDisplay;
		resultMessage.style.display = 'block';
	},

	// hides the result of the last send
	hideResult : function()
	{
		// todo: fade these opacities
		document.getElementById('resultMessage').style.display = 'none';
	},

	// turns the widget over (to end up oon the preferences panel)
	flipToBack : function()
	{
		var front = document.getElementById("front");
		var back = document.getElementById("prefs");
	
		// set widget size and freeze display
		if (window.widget)
		{
			window.resizeTo(244,264);
			widget.prepareForTransition("ToBack");
		}

		// turn off front - turn on back
		front.style.display="none";
		back.style.display="block";

		// focus on the mailhost field
		document.getElementById("mailHost").focus();

		// flip the widget over
		if (window.widget)
		{
			setTimeout('widget.performTransition();', 0);
		}
	},
	

	// turns the widget over (to end up on the face of the stamp)
	flipToFront : function()
	{
		var front = document.getElementById("front");
		var back = document.getElementById("prefs");

		// set widget size and freeze display
		if(window.widget)
		{
			window.resizeTo(244,264);
			widget.prepareForTransition("ToFront");
		}

		// turn off back - turn on front
		back.style.display="none";
		front.style.display="block";

		// flip the widget over
		if (window.widget)
		{
			setTimeout('widget.performTransition();', 0);
		}
	},	


	// fade in the info button
	showFlipButton : function()
	{
		this.flipButton.showInfoButton();
	},

	// fade out the info button	
	hideFlipButton : function()
	{
		this.flipButton.hideInfoButton();
	},


	// highlight info button (for mouse over)
	highlightFlipButton : function()
	{
		document.getElementById('infoButton').src = 'Images/flip_button_hover.png';
	},


	// remove highlight from info button (for mouse out)
	unhighlightFlipButton : function()
	{
		document.getElementById('infoButton').src = 'Images/flip_button.png';
	},


	// starts the progress indicator spinning
	startProgressIndicator : function()
	{
		this.progInd.start();
	},


	// stops the progress indicator from spinning
	stopProgressIndicator : function()
	{
		this.progInd.stop();
	},


	// gets the email from the field on the prefs
	getUserEmail : function()
	{
		return document.getElementById("useremail").value;
	},

	// gets the password from the field on the prefs
	getPassword : function()
	{
		return document.getElementById("password").value;
	},

	// gets the mail host (gmail/yahoo) from the field on the prefs
	getMailHost : function()
	{
		return document.getElementById("mailHost").value;
	},

	getUsername : function()
	{
		return document.getElementById("username").value;
	},

	getOtherMailHost : function()
	{
		return document.getElementById("otherMailHost").value;
	},

	getPort : function()
	{
		return document.getElementById("port").value;
	},

	getUseSSL : function()
	{
		return document.getElementById("useSSL").checked;
	},

	// sets the email in the field on the prefs
	setUserEmail : function(useremail)
	{
		document.getElementById("useremail").value = useremail;
	},

	// sets the password in the field on the prefs
	setPassword : function(password)
	{
		document.getElementById("password").value = password;
	},

	// sets the mail host in the field on the prefs
	setMailHost : function(host)
	{
		document.getElementById("mailHost").value = host;
	},

	setUsername : function(username)
	{
		document.getElementById("username").value = username;
	},

	setOtherMailHost : function(mailhost)
	{
		document.getElementById("otherMailHost").value = mailhost;
	},

	setPort : function(port)
	{
		document.getElementById("port").value = port;
	},

	setUseSSL : function(useSSL)
	{
		document.getElementById("useSSL").checked = useSSL;
	},

	// change recipient
	changeRecipient : function()
	{
		this.recipientList.dropdownChanged();
		this.recipientList.textbox.focus();
	},

	selectRecipient : function()
	{
		this.selectField(document.getElementById('recipient'));
	},

	highlightRecipient : function()
	{
		this.changeSelectBorderImages('recipientFakeBorder','_focused');
	},

	unhighlightRecipient : function()
	{
		this.changeSelectBorderImages('recipientFakeBorder','');
	},

	// change subject
	changeSubject : function()
	{
		this.subjectList.dropdownChanged();
		this.subjectList.textbox.focus();
	},

	selectSubject : function()
	{
		this.selectField(document.getElementById('subject'));
	},
	
	selectField : function(element)
	{
		// highlight the text in the given field
		element.setSelectionRange(0,element.value.length);
	},

	highlightSubject : function()
	{
		this.changeSelectBorderImages('subjectFakeBorder','_focused');
	},

	unhighlightSubject : function()
	{
		this.changeSelectBorderImages('subjectFakeBorder','');
	},

	changeSelectBorderImages : function(elementPrefix, imageSuffix)
	{
		document.getElementById(elementPrefix+'Left').src = 'Images/select_border_left'+imageSuffix+'.png';
		document.getElementById(elementPrefix+'Top').src = 'Images/select_border_top'+imageSuffix+'.png';
		document.getElementById(elementPrefix+'Right').src = 'Images/select_border_right'+imageSuffix+'.png';
		document.getElementById(elementPrefix+'Bottom').src = 'Images/select_border_bottom'+imageSuffix+'.png';
	},

	selectMessage : function()
	{
		this.selectField(document.getElementById('messageBody'));
	},

	highlightMessage : function()
	{
		this.changeMessageBorderImages('messageFakeBorder','_focused');
	},

	unhighlightMessage : function()
	{
		this.changeMessageBorderImages('messageFakeBorder','');
	},

	changeMessageBorderImages : function(elementPrefix, imageSuffix)
	{
		document.getElementById(elementPrefix+'Left').src = 'Images/message_border_left'+imageSuffix+'.png';
		document.getElementById(elementPrefix+'Top').src = 'Images/message_border_top'+imageSuffix+'.png';
		document.getElementById(elementPrefix+'Right').src = 'Images/message_border_right'+imageSuffix+'.png';
		document.getElementById(elementPrefix+'Bottom').src = 'Images/message_border_bottom'+imageSuffix+'.png';
	},

	// stores the values in the textboxes into the dropdown lists
	addValuesToDropdowns : function()
	{
		this.recipientList.updateDropdownFromText();
		this.subjectList.updateDropdownFromText();
	},
	
	getSubject : function()
	{
		return this.subjectList.getValue();
	},

	getRecipient : function()
	{
		return this.recipientList.getValue();
	},

	getMessage : function()
	{
		return document.getElementById('messageBody').value;
	},

	showExtraOptions : function(show)
	{
		var newStyle = 'none';
		if (show)
		{
			newStyle = "block";
		}

		document.getElementById('usernameLabel').style.display = newStyle;
		document.getElementById('usernameField').style.display = newStyle;
		document.getElementById('otherMailHostLabel').style.display = newStyle;
		document.getElementById('otherMailHostField').style.display = newStyle;
		document.getElementById('portLabel').style.display = newStyle;
		document.getElementById('portField').style.display = newStyle;
		document.getElementById('sslLabel').style.display = newStyle;
		document.getElementById('sslField').style.display = newStyle;

		if (show)
		{
			document.getElementById('useremailLabel').style.top = "115px";
			document.getElementById('useremailField').style.top = "115px";
			document.getElementById('passwordLabel').style.top = "165px";
			document.getElementById('passwordField').style.top = "165px";			
		} else {
			document.getElementById('useremailLabel').style.top = "60px";
			document.getElementById('useremailField').style.top = "60px";
			document.getElementById('passwordLabel').style.top = "85px";
			document.getElementById('passwordField').style.top = "85px";			
		}
	}

}
